@@ -101,7 +101,7 @@ ggvenn <- function(
   text_color = "black",
   text_size = 4,
   comma_sep = FALSE,
-  padding = 1,
+  padding = 0.2,
   max_elements = 6,
   text_truncate = TRUE
 ) {
